pitchtools.list_octave_transpositions_of_pitch_carrier_within_pitch_range
=========================================================================

.. autofunction:: abjad.tools.pitchtools.list_octave_transpositions_of_pitch_carrier_within_pitch_range.list_octave_transpositions_of_pitch_carrier_within_pitch_range
